int YOUNGHEAP_Init(tAllocatorHeap* heap);
int YOUNGHEAP_ISHANDLE(tAllocatorHeap* heap, tOBREF h);
